@@ -6,11 +6,11 @@ extern "C" TSLanguage *tree_sitter_c_sharp();
 
 // "tree-sitter", "language" hashed with BLAKE2
 const napi_type_tag LANGUAGE_TYPE_TAG = {
-  0x8AF2E5212AD58ABF, 0xD5006CAD83ABBA16
+    0x8AF2E5212AD58ABF, 0xD5006CAD83ABBA16
 };
 
 Napi::Object Init(Napi::Env env, Napi::Object exports) {
-    exports["name"] = Napi::String::New(env, "c_sharp");
+    exports["name"] = Napi::String::New(env, "c-sharp");
     auto language = Napi::External<TSLanguage>::New(env, tree_sitter_c_sharp());
     language.TypeTag(&LANGUAGE_TYPE_TAG);
     exports["language"] = language;
